/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.examples.simpleloaderhook;

import java.net.URL;
import java.security.ProtectionDomain;
import java.util.ArrayList;
import org.eclipse.equinox.adaptor.EquinoxData;
import org.eclipse.equinox.adaptor.hooks.EquinoxLoaderHook;
import org.eclipse.equinox.adaptor.loader.ClasspathEntry;
import org.eclipse.equinox.adaptor.loader.EquinoxLoader;
import org.eclipse.equinox.bundlefile.BundleEntry;

/**
 * A simple loader hook which prints status of class/resource loads to standard out.
 */
public class SimpleLoaderHook implements EquinoxLoaderHook {

	public void preFindLocalClass(String name, EquinoxLoader loader) throws ClassNotFoundException {
		System.out.println("Attempting to load class " + name + " from bundle " + loader.getBundleData().getSymbolicName());
	}

	public void postFindLocalClass(String name, Class clazz, EquinoxLoader loader) {
		if (clazz == null)
			System.out.println("Failed to load class " + name + " from bundle " + loader.getBundleData().getSymbolicName());
		else
			System.out.println("Successfully loaded class " + name + " from bundle " + loader.getBundleData().getSymbolicName());
	}

	public void preFindLocalResource(String name, EquinoxLoader loader) {
		System.out.println("Attempting to load resource " + name + " from bundle " + loader.getBundleData().getSymbolicName());
	}

	public void postFindLocalResource(String name, URL resource, EquinoxLoader loader) {
		if (resource == null)
			System.out.println("Failed to load resource " + name + " from bundle " + loader.getBundleData().getSymbolicName());
		else
			System.out.println("Successfully loaded resource" + name + " from bundle " + loader.getBundleData().getSymbolicName());
	}

	public byte[] processClass(String name, byte[] classbytes, ClasspathEntry classpathEntry, BundleEntry entry, EquinoxLoader loader) {
		// do nothing
		return null;
	}

	public boolean addClassPathEntry(ArrayList cpEntries, String cp, EquinoxLoader hostloader, EquinoxData sourcedata, ProtectionDomain sourcedomain) {
		// do nothing
		return false;
	}

}
